# UserPermissionAction


## Enum

* `CREATE` (value: `'create'`)

* `READ` (value: `'read'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


